@@ -3,7 +3,7 @@ package Test::Harness::Straps;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.23';
+$VERSION = '0.26';
 
 use Config;
 use Test::Harness::Assert;
@@ -167,39 +167,33 @@ sub _analyze_line {
         # happens often on VMS if you do:
         #   print "not " unless $test;
         #   print "ok $num\n";
-        if( $self->{saw_lone_not} && 
-            ($self->{lone_not_line} == $self->{line} - 1) ) 
-        {
+        if ( $self->{lone_not_line} && ($self->{lone_not_line} == $self->{line} - 1) ) {
             $point->set_ok( 0 );
         }
 
-        my $pass = $point->ok;
         if ( $self->{todo}{$point->number} ) {
             $point->set_directive_type( 'todo' );
         }
 
         if ( $point->is_todo ) {
             $totals->{todo}++;
-            $pass = 1;
             $totals->{bonus}++ if $point->ok;
         }
         elsif ( $point->is_skip ) {
             $totals->{skip}++;
-            $pass = 1;
         }
 
-        $totals->{ok}++ if $pass;
+        $totals->{ok}++ if $point->pass;
 
-        if ( ($point->number > 100000) && ($point->number > $self->{max}) ) {
-            warn "Enormous test number seen [test ", $point->number, "]\n";
-            warn "Can't detailize, too big.\n";
+        if ( ($point->number > 100_000) && ($point->number > ($self->{max}||100_000)) ) {
+            if ( !$self->{too_many_tests}++ ) {
+                warn "Enormous test number seen [test ", $point->number, "]\n";
+                warn "Can't detailize, too big.\n";
+            }
         }
         else {
-            #Generates the details based on the last test line seen.  C<$pass> is
-            #true if it was considered to be a passed test.  C<%test> is the results
-            #of the test you're summarizing.
             my $details = {
-                ok          => $pass,
+                ok          => $point->pass,
                 actual_ok   => $point->ok,
                 name        => _def_or_blank( $point->description ),
                 type        => _def_or_blank( $point->directive_type ),
@@ -207,10 +201,6 @@ sub _analyze_line {
             };
 
             assert( defined( $details->{ok} ) && defined( $details->{actual_ok} ) );
-
-            # We don't want these to be undef because they are often
-            # checked and don't want the checker to have to deal with
-            # uninitialized vars.
             $totals->{details}[$point->number - 1] = $details;
         }
     } # test point
@@ -218,7 +208,6 @@ sub _analyze_line {
         $linetype = 'other';
         # Sometimes the "not " and "ok" will be on separate lines on VMS.
         # We catch this and remember we saw it.
-        $self->{saw_lone_not} = 1;
         $self->{lone_not_line} = $self->{line};
     }
     elsif ( $self->_is_header($line) ) {
@@ -368,9 +357,8 @@ such as a PHP interpreter for a PHP-based strap.
 sub _command {
     my $self = shift;
 
-    return $ENV{HARNESS_PERL}           if defined $ENV{HARNESS_PERL};
-    return "MCR $^X"                    if $self->{_is_vms};
-    return Win32::GetShortPathName($^X) if $self->{_is_win32};
+    return $ENV{HARNESS_PERL}   if defined $ENV{HARNESS_PERL};
+    return qq["$^X"]            if $self->{_is_win32} && ($^X =~ /[^\w\.\/\\]/);
     return $^X;
 }
 
@@ -470,7 +458,8 @@ sub _filtered_INC {
 	# toss the ones that involve perl_root, the install location
         @inc = grep !/perl_root/i, @inc;
 
-    } elsif ( $self->{_is_win32} ) {
+    }
+    elsif ( $self->{_is_win32} ) {
 	# Lose any trailing backslashes in the Win32 paths
 	s/[\\\/+]$// foreach @inc;
     }
@@ -615,11 +604,10 @@ etc. so it's ready to parse the next file.
 sub _reset_file_state {
     my($self) = shift;
 
-    delete @{$self}{qw(max skip_all todo)};
+    delete @{$self}{qw(max skip_all todo too_many_tests)};
     $self->{line}       = 0;
     $self->{saw_header} = 0;
     $self->{saw_bailout}= 0;
-    $self->{saw_lone_not} = 0;
     $self->{lone_not_line} = 0;
     $self->{bailout_reason} = '';
     $self->{'next'}       = 1;
@@ -676,8 +664,8 @@ See F<examples/mini_harness.plx> for an example of use.
 
 =head1 AUTHOR
 
-Michael G Schwern C<< <schwern@pobox.com> >>, currently maintained by
-Andy Lester C<< <andy@petdance.com> >>.
+Michael G Schwern C<< <schwern at pobox.com> >>, currently maintained by
+Andy Lester C<< <andy at petdance.com> >>.
 
 =head1 SEE ALSO
 
